==> cssfinder-0.3.0.tar.gz: cssfinder-0.3.0/cssfinder/enums.py <==
# Copyright 2023 Krzysztof Wiśniewski <argmaster.world@gmail.com>
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the “Software”), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be included in all copies
# or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
# CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
# OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


"""Module contains utility enums used within the cssfinder project."""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing_extensions import Self


class CaseInsensitiveEnum(Enum):
    """Case insensitive enum base class."""

    @classmethod
    def _missing_(cls, value: object) -> Self:
        name = str(value)
        for member in cls:
            if member.name.casefold() == name.casefold():
                return member

        reason = f"No enum value matches name {name!r}."
        raise NoMatchingEnumValueError(reason)


class NoMatchingEnumValueError(AttributeError):
    """Raised when CaseInsensitiveEnum subclass can't find matching enum value."""

==> cssfinder-0.4.0.tar.gz: cssfinder-0.4.0/cssfinder/enums.py <==
# Copyright 2023 Krzysztof Wiśniewski <argmaster.world@gmail.com>
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the “Software”), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be included in all copies
# or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
# CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
# OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


"""Module contains utility enums used within the cssfinder project."""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing_extensions import Self


class CaseInsensitiveEnum(Enum):
    """Case insensitive enum base class."""

    @classmethod
    def _missing_(cls, value: object) -> Self:
        name = str(value)
        for member in cls:
            if member.name.casefold() == name.casefold():
                return member

        reason = f"No enum value matches name {name!r}."
        raise NoMatchingEnumValueError(reason)


class NoMatchingEnumValueError(AttributeError):
    """Raised when CaseInsensitiveEnum subclass can't find matching enum value."""


class ExitCode:
    """Enumeration of standardized CSSFinder exit codes."""

    EXAMPLE_SHA_NOR_NAME_GIVEN = 67465
    EXAMPLE_WITH_NAME_NOT_FOUND = 67470
    EXAMPLE_WITH_SHA_NOT_FOUND = 67475

    EXAMPLE_DESTINATION_ALREADY_EXISTS = 67480
